@@ -13,8 +13,26 @@
 // of the License or (at your option) any later version.
 // (see http://www.opensource.org/licenses for more info)
 
+// RcppArmadillo: add the R defines
 #include <Rconfig.h>
 
+#if !defined(ARMA_USE_LAPACK)
+#define ARMA_USE_LAPACK
+#endif
+
+#if !defined(ARMA_USE_BLAS)
+#define ARMA_USE_BLAS
+#endif
+
+// #define ARMA_USE_ATLAS
+// #define ARMA_ATLAS_INCLUDE_DIR /usr/include/
+//// If you're using ATLAS and the compiler can't find cblas.h and/or clapack.h
+//// uncomment the above define and specify the appropriate include directory.
+//// Make sure the directory has a trailing /
+
+// #define ARMA_USE_BOOST
+// #define ARMA_USE_BOOST_DATE
+
 #define ARMA_HAVE_STD_ISFINITE
 #define ARMA_HAVE_STD_ISINF
 #define ARMA_HAVE_STD_ISNAN
@@ -23,26 +41,8 @@
 #define ARMA_HAVE_LOG1P
 #define ARMA_HAVE_GETTIMEOFDAY
 
-/* #undef ARMA_USE_ATLAS */
-#define ARMA_USE_LAPACK
-#define ARMA_USE_BLAS
-
-#ifndef HAVE_F77_UNDERSCORE
-#pragma message (** armadillo calls to BLAS and Lapack disabled **)
-#undef ARMA_USE_LAPACK
-#undef ARMA_USE_BLAS
-#endif
-/* #undef ARMA_USE_BOOST */
-/* #undef ARMA_USE_BOOST_DATE */
-
-/* #undef ARMA_EXTRA_DEBUG */
-/* #undef ARMA_NO_DEBUG */
-
-#if defined(ARMA_USE_ATLAS)
-  #if !defined(ARMA_ATLAS_INCLUDE_DIR)
-    #define ARMA_ATLAS_INCLUDE_DIR  /usr/include
-  #endif
-#endif
+// #define ARMA_EXTRA_DEBUG
+// #define ARMA_NO_DEBUG
 
+// RcppArmadillo: add the RcppArmadillo configuration
 #include <RcppArmadilloConfig.h>
-
