@@ -30,8 +30,7 @@ linspace
   (
   const typename vec_type::pod_type start,
   const typename vec_type::pod_type end,
-  const u32 num,
-  const u32 dim = 0
+  const u32 num
   )
   {
   arma_extra_debug_sigprint();
@@ -40,29 +39,38 @@ linspace
   
   arma_debug_check( (num < 2), "linspace(): num must be >= 2");
   
-  arma_warn( (dim != 0), "linspace(): the 'dim' argument is deprecated -- please use template based specification instead" );
-  
   typedef typename vec_type::elem_type eT;
   typedef typename vec_type::pod_type   T;
   
-  // // this will be the default in the future:
-  // const u32 n_rows = (is_Row<vec_type>::value == true) ? 1   : num;
-  // const u32 n_cols = (is_Row<vec_type>::value == true) ? num : 1;
-  
-  // for temporary compatibility with old user code:
-  const u32 n_rows = (is_Row<vec_type>::value == true) ? 1   : ( (dim == 0) ? num : 1   );
-  const u32 n_cols = (is_Row<vec_type>::value == true) ? num : ( (dim == 0) ? 1   : num );
-  
-  const eT delta = (end-start)/T(num-1);
+  const u32 n_rows = (is_Row<vec_type>::value == true) ? 1   : num;
+  const u32 n_cols = (is_Row<vec_type>::value == true) ? num : 1;
   
   Mat<eT> x(n_rows, n_cols);
   eT* x_mem = x.memptr();
   
-  x_mem[0] = start;
+  const u32 num_m1 = num - 1;
   
-  for(u32 i=1; i<num; ++i)
+  if(is_non_integral<T>::value == true)
     {
-    x_mem[i] = x_mem[i-1] + delta;
+    const T delta = (end-start)/T(num_m1);
+    
+    for(u32 i=0; i<num_m1; ++i)
+      {
+      x_mem[i] = eT(start + i*delta);
+      }
+    
+    x_mem[num_m1] = eT(end);
+    }
+  else
+    {
+    const double delta = (end >= start) ? double(end-start)/double(num_m1) : -double(start-end)/double(num_m1);
+    
+    for(u32 i=0; i<num_m1; ++i)
+      {
+      x_mem[i] = eT(double(start) + i*delta);
+      }
+    
+    x_mem[num_m1] = eT(end);
     }
   
   return x;
@@ -72,10 +80,10 @@ linspace
 
 inline
 mat
-linspace(const double start, const double end, const u32 num, const u32 dim = 0)
+linspace(const double start, const double end, const u32 num)
   {
   arma_extra_debug_sigprint();
-  return linspace<mat>(start, end, num, dim);
+  return linspace<mat>(start, end, num);
   }
 
 
@@ -235,7 +243,7 @@ imag(const BaseCube<std::complex<typename T1::pod_type>,T1>& X)
 
 template<typename eT>
 inline
-eT
+typename arma_float_only<eT>::result
 log_add(eT log_a, eT log_b)
   {
   if(log_a < log_b)
@@ -288,33 +296,6 @@ log(const BaseCube<typename T1::elem_type,T1>& A)
 
 
 
-//
-// trunc_log
-
-template<typename T1>
-arma_inline
-const eOp<T1, eop_trunc_log>
-trunc_log(const Base<typename T1::elem_type,T1>& A)
-  {
-  arma_extra_debug_sigprint();
-  
-  return eOp<T1, eop_trunc_log>(A.get_ref());
-  }
-
-
-
-template<typename T1>
-arma_inline
-const eOpCube<T1, eop_cube_trunc_log>
-trunc_log(const BaseCube<typename T1::elem_type,T1>& A)
-  {
-  arma_extra_debug_sigprint();
-  
-  return eOpCube<T1, eop_cube_trunc_log>(A.get_ref());
-  }
-
-
-
 //
 // log10
 
@@ -369,33 +350,6 @@ exp(const BaseCube<typename T1::elem_type,T1>& A)
 
 
 
-//
-// trunc_exp
-
-template<typename T1>
-arma_inline
-const eOp<T1, eop_trunc_exp>
-trunc_exp(const Base<typename T1::elem_type,T1>& A)
-  {
-  arma_extra_debug_sigprint();
-  
-  return eOp<T1, eop_trunc_exp>(A.get_ref());
-  }
-
-
-
-template<typename T1>
-arma_inline
-const eOpCube<T1, eop_cube_trunc_exp>
-trunc_exp(const BaseCube<typename T1::elem_type,T1>& A)
-  {
-  arma_extra_debug_sigprint();
-  
-  return eOpCube<T1, eop_cube_trunc_exp>(A.get_ref());
-  }
-
-
-
 //
 // abs
 
