@@ -23,7 +23,12 @@
 template<typename T1>
 inline
 const Op<T1, op_pinv>
-pinv(const Base<typename T1::elem_type,T1>& X, const typename T1::elem_type tol = 0.0)
+pinv
+  (
+  const Base<typename T1::elem_type,T1>& X,
+  const typename T1::elem_type tol = 0.0,
+  const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0
+  )
   {
   arma_extra_debug_sigprint();
   
