@@ -18,54 +18,20 @@
 //! @{
 
 
-
-//! Generate a dense matrix with all elements set to random values with a gaussian distribution (zero mean, unit variance)
-arma_inline
-const eOp<mat, eop_randn>
-randn(const u32 n_rows, const u32 n_cols)
+inline
+double
+randn()
   {
-  arma_extra_debug_sigprint();
-  
-  return eOp<mat, eop_randn>(n_rows, n_cols);
+  return double(eop_aux_randn<double>());
   }
 
 
-
-arma_inline
-const eOpCube<cube, eop_cube_randn>
-randn(const u32 n_rows, const u32 n_cols, const u32 n_slices)
+template<typename eT>
+inline
+typename arma_scalar_only<eT>::result
+randn()
   {
-  arma_extra_debug_sigprint();
-  
-  return eOpCube<cube, eop_cube_randn>(n_rows, n_cols, n_slices);
-  }
-
-
-
-template<typename mat_type>
-arma_inline
-const eOp<mat_type, eop_randn>
-randn(const u32 n_rows, const u32 n_cols)
-  {
-  arma_extra_debug_sigprint();
-  
-  arma_type_check<is_Mat<mat_type>::value == false>::apply();
-  
-  return eOp<mat_type, eop_randn>(n_rows, n_cols);
-  }
-
-
-
-template<typename cube_type>
-arma_inline
-const eOpCube<cube_type, eop_cube_randn>
-randn(const u32 n_rows, const u32 n_cols, const u32 n_slices)
-  {
-  arma_extra_debug_sigprint();
-  
-  arma_type_check<is_Cube<cube_type>::value == false>::apply();
-  
-  return eOpCube<cube_type, eop_cube_randn>(n_rows, n_cols, n_slices);
+  return eT(eop_aux_randn<eT>());
   }
 
 
@@ -73,7 +39,7 @@ randn(const u32 n_rows, const u32 n_cols, const u32 n_slices)
 //! Generate a vector with all elements set to random values with a gaussian distribution (zero mean, unit variance)
 arma_inline
 const eOp<colvec, eop_randn>
-randn(const u32 n_elem)
+randn(const u32 n_elem, const arma_Mat_Col_Row_only<colvec>::result* junk = 0)
   {
   arma_extra_debug_sigprint();
   
@@ -85,12 +51,10 @@ randn(const u32 n_elem)
 template<typename vec_type>
 arma_inline
 const eOp<vec_type, eop_randn>
-randn(const u32 n_elem)
+randn(const u32 n_elem, const typename arma_Mat_Col_Row_only<vec_type>::result* junk = 0)
   {
   arma_extra_debug_sigprint();
   
-  arma_type_check< (is_Col<vec_type>::value == false) && (is_Row<vec_type>::value == false) >::apply();
-  
   if(is_Row<vec_type>::value == true)
     {
     return eOp<vec_type, eop_randn>(1, n_elem);
@@ -103,4 +67,51 @@ randn(const u32 n_elem)
 
 
 
+//! Generate a dense matrix with all elements set to random values with a gaussian distribution (zero mean, unit variance)
+arma_inline
+const eOp<mat, eop_randn>
+randn(const u32 n_rows, const u32 n_cols, const arma_Mat_Col_Row_only<mat>::result* junk = 0)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOp<mat, eop_randn>(n_rows, n_cols);
+  }
+
+
+
+template<typename mat_type>
+arma_inline
+const eOp<mat_type, eop_randn>
+randn(const u32 n_rows, const u32 n_cols, const typename arma_Mat_Col_Row_only<mat_type>::result* junk = 0)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOp<mat_type, eop_randn>(n_rows, n_cols);
+  }
+
+
+
+arma_inline
+const eOpCube<cube, eop_cube_randn>
+randn(const u32 n_rows, const u32 n_cols, const u32 n_slices, const arma_Cube_only<cube>::result* junk = 0)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOpCube<cube, eop_cube_randn>(n_rows, n_cols, n_slices);
+  }
+
+
+
+template<typename cube_type>
+arma_inline
+const eOpCube<cube_type, eop_cube_randn>
+randn(const u32 n_rows, const u32 n_cols, const u32 n_slices, const typename arma_Cube_only<cube_type>::result* junk = 0)
+  {
+  arma_extra_debug_sigprint();
+  
+  return eOpCube<cube_type, eop_cube_randn>(n_rows, n_cols, n_slices);
+  }
+
+
+
 //! @}
